==> micropype-0.2.2-py3-none-any.whl: micropype/utils.py <==
from enum import Enum
from os import makedirs
import os.path as op
from colorama import Style, Fore
from datetime import datetime


def check_dir(*args, dir_exist_ok=True) -> str:
    path = op.abspath(op.join(*args))
    if op.isfile(path):
        path, _ = op.split(path)
        # raise IOError(f'{path} is a file instead of a directory.')
    if not dir_exist_ok and op.isdir(path):
        raise IOError(f'{path} already exist.')
    makedirs(path, exist_ok=True)
    return path


def datetime_str():
    return datetime.isoformat(datetime.now())[:-4]

class MessageIntent(Enum):
    DEFAULT=0
    INFO=1
    SUCCESS=2
    ERROR=3
    WARNING=4
    HIGHLIGHT=5

def cprint(*args, intent:MessageIntent=MessageIntent.DEFAULT):
    """ Print a (optionally colored) message with the date and time"""
    if intent == MessageIntent.INFO: clr = Fore.BLUE
    elif intent == MessageIntent.SUCCESS: clr = Fore.GREEN
    elif intent == MessageIntent.ERROR: clr = Fore.RED
    elif intent == MessageIntent.WARNING: clr = Fore.YELLOW
    elif intent == MessageIntent.HIGHLIGHT: clr = Fore.LIGHTMAGENTA_EX
    else: clr = Fore.WHITE
    print(f'{datetime_str()}:', clr, " ".join(str(a) for a in args), Style.RESET_ALL)


def merge_dicts(a: dict, b: dict) -> dict:
    """ Override a with b values 

        If a keys dot not exists in b, it is created
    """
    for key in b:
        if key in a and isinstance(a[key], dict) and isinstance(b[key], dict):
            a[key] = merge_dicts(a[key], b[key])
        else:
            a[key] = b[key]
    return a



def cast_to_type(value: str):
    """ Convert string to float, int, list or dict is possible """
    # Try float
    try:
        return float(value)
    except ValueError:
        pass

    # Try int
    try:
        return int(value)
    except ValueError:
        pass

    # Try list or dict
    try:
        if value.startswith("[") and value.endswith("]"):
            return eval(value)  # Convertir en list
        elif value.startswith("{") and value.endswith("}"):
            return eval(value)  # Convertir en dict
    except (SyntaxError, ValueError):
        pass

    # Then it is a str
    return value

==> micropype-0.3.1-py3-none-any.whl: micropype/utils.py <==
from enum import Enum
from os import makedirs
import os.path as op
from colorama import Style, Fore
from datetime import datetime


def check_dir(*args, dir_exist_ok=True) -> str:
    path = op.abspath(op.join(*args))
    if op.isfile(path):
        path, _ = op.split(path)
        # raise IOError(f'{path} is a file instead of a directory.')
    if not dir_exist_ok and op.isdir(path):
        raise IOError(f'{path} already exist.')
    makedirs(path, exist_ok=True)
    return path


def datetime_str():
    return datetime.isoformat(datetime.now())[:-4]

class MessageIntent(Enum):
    DEFAULT=0
    INFO=1
    SUCCESS=2
    ERROR=3
    WARNING=4
    HIGHLIGHT=5

def cprint(*args, intent:MessageIntent=MessageIntent.DEFAULT):
    """ Print a (optionally colored) message with the date and time"""
    if intent == MessageIntent.INFO: clr = Fore.BLUE
    elif intent == MessageIntent.SUCCESS: clr = Fore.GREEN
    elif intent == MessageIntent.ERROR: clr = Fore.RED
    elif intent == MessageIntent.WARNING: clr = Fore.YELLOW
    elif intent == MessageIntent.HIGHLIGHT: clr = Fore.LIGHTMAGENTA_EX
    else: clr = Fore.WHITE
    print(f'{datetime_str()}:', clr, " ".join(str(a) for a in args), Style.RESET_ALL)


def merge_dicts(a: dict, b: dict) -> dict:
    """ Override a with b values 

        If a keys dot not exists in b, it is created
    """
    for key in b:
        if key in a and isinstance(a[key], dict) and isinstance(b[key], dict):
            a[key] = merge_dicts(a[key], b[key])
        else:
            a[key] = b[key]
    return a



def auto_cast(value: str):
    """ Convert string to float, int, list or dict is possible """
    # # Try float
    # try:
    #     return float(value)
    # except ValueError:
    #     pass

    # # Try int
    # try:
    #     return int(value)
    # except ValueError:
    #     pass

    # # Try list or dict
    # try:
    #     if value.startswith("[") and value.endswith("]"):
    #         return eval(value)  # Convertir en list
    #     if value.startswith("(") and value.endswith(")"):
    #         return eval(value)  # Convertir en list
    #     elif value.startswith("{") and value.endswith("}"):
    #         return eval(value)  # Convertir en dict
    # except (SyntaxError, ValueError):
    #     pass
    try:
        return eval(value)
    except:
        return value
